#
# spec file for package perf
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perf
%define version %(rpm -q --qf '%{VERSION}' kernel-source)
Version:        %{version}
Release:        39.5
Summary:        Performance Monitoring Tools for Linux
License:        GPL-2.0
Group:          Development/Tools/Debuggers
Url:            https://perf.wiki.kernel.org/
BuildRequires:  asciidoc
BuildRequires:  audit-devel
BuildRequires:  binutils-devel
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gtk2-devel
BuildRequires:  kernel-source >= 2.6.31
BuildRequires:  libdw-devel
BuildRequires:  libelf-devel
BuildRequires:  xz-devel
%ifarch aarch64 ia64 x86_64 ppc64 ppc64le ppc %sparc
BuildRequires:  libnuma-devel
%endif
%ifarch s390x s390
%define         _perf_unwind NO_LIBUNWIND=1
%else
%define         _perf_unwind %{nil}
BuildRequires:  libunwind-devel
%endif
BuildRequires:  newt-devel
BuildRequires:  openssl-devel
BuildRequires:  xmlto
BuildRequires:  zlib-devel
%{perl_requires}
%{?libperl_requires}

Requires:       kernel >= 2.6.31
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides a userspace tool 'perf', which monitors performance for
either unmodified binaries or the entire system. It requires a Linux kernel
which includes the Performance Counters for Linux (PCL) subsystem (>= 2.6.31).
This subsystem utilizes the Performance Monitoring Unit (PMU) / hardware
counters of the underlying cpu architecture (if supported).

%prep
# copy necessary files from kernel-source since we need to modify them
(cd /usr/src/linux ; tar -cf - COPYING CREDITS README tools include scripts Kbuild Makefile arch/*/{include,lib,Makefile} lib) | tar -xf - 
chmod +x tools/perf/util/generate-cmdlist.sh

%build
cd tools/perf
export WERROR=0
# PASS rpm optflags as EXTRA_FLAGS,  passing as CFLAGS overrides and breaks build
make %{?_smp_mflags} -f Makefile.perf EXTRA_CFLAGS="%{optflags}" ASCIIDOC8=1 prefix=/usr libdir=%{_libdir} perfexecdir=lib/%{name}-core all doc %{_perf_unwind} tipdir=share/doc/packages/perf

%install
cd tools/perf
export WERROR=0
make -f Makefile.perf V=1 EXTRA_CFLAGS="%{optflags}" prefix=/usr libdir=%{_libdir} perfexecdir=lib/%{name}-core DESTDIR=%{buildroot} install install-doc %{_perf_unwind} tipdir=share/doc/packages/perf

%files
%defattr(-, root, root)
%attr(0644, root, root) %doc COPYING CREDITS README tools/perf/design.txt
%if 0%{?suse_version} > 1315
%attr(0644, root, root) %doc %{_docdir}/perf/tips.txt
%endif
%{_bindir}/perf
%{_bindir}/trace
%{_libdir}/libperf-gtk.so
%ifnarch armv7l
%dir %{_libdir}/traceevent
%dir %{_libdir}/traceevent/plugins
%{_libdir}/traceevent/plugins/plugin_*.so
%endif
%attr(0644, -, -) %{_sysconfdir}/bash_completion.d/perf
%{_libexecdir}/%{name}-core
%{_datarootdir}/%{name}-core
%{_mandir}/man1/perf*

%changelog
* Thu Sep  1 2016 tonyj@suse.com
- Fix build error (tips.txt) on Leap42.2
- Fix doc file attributes
* Mon Jun  6 2016 jslaby@suse.com
- disable Werror completely. It breaks build due to shadow variables
  in external (perl) headers.
- add %%{?_smp_mflags}
* Mon Apr  4 2016 tonyj@suse.com
- Package perf-tips as docs.
- Include support for xz compressed images
* Mon Jan 11 2016 tonyj@suse.com
- Support strace/data.
* Sun Oct 11 2015 dmueller@suse.com
- enable numa support for aarch64
* Thu Jul 16 2015 antoine.belvire@laposte.net
- Remove perf-fix-branch-stack-mode-cannot-be-set.patch (upstreamed).
* Sun Jun 28 2015 antoine.belvire@laposte.net
- Fix build with GCC 5
  * perf-fix-branch-stack-mode-cannot-be-set.patch
* Wed May 13 2015 tonyj@suse.com
- Fix ppc64/ppc64le breakage due to libexecdir/libdir
* Mon Mar  9 2015 dimstar@opensuse.org
- Inject libdir=%%{_libdir} into make calls.
* Thu Jan  8 2015 dimstar@opensuse.org
- Remove build hack for kernel not building against glibc 2.20.
* Thu Nov 27 2014 dimstar@opensuse.org
- Build hack: if util/util.h does not (yet) define _DEFAULT_SOURCE,
  we export WERROR=0, which removes -Werror from CFLAGS. Once a
  kernel lands that defines _DEFAULT_SOURCE, we fail the build in
  to remove this hack, making it a (hopefully_ short-livinging one.
* Fri Jun 27 2014 tonyj@suse.com
- Build for s390[x] without libunwind (bnc#882855)
* Tue Mar 25 2014 aj@ajaissle.de
- Fix current build including 'trace event' plugins
- Do not include 'trace event' plugins when on armv7l
- BuildRequire libnuma-devel to enable 'perf bench numa mem', but
  only require if we build for ia64 x86_64 ppc64 ppc64le  ppc %%sparc
- Spec cleanup:
  * Add Url: https://perf.wiki.kernel.org/
  * Drop %%clean-section: We don't need to cleanup the buildroot
  * bash_completion.d/perf doesn't need executable bit
* Fri Jan 24 2014 tonyj@suse.com
- Fix build errors (invoke Makefile.perf directly to pass perfexecdir)
- Add /usr/bin/trace alias for perf (mainline b52bc234)
- Add libperf-gtk.so (loaded via dlsym, mainline fc67297b)
* Wed Dec  4 2013 tonyj@suse.com
- Drop patch perl-5.18-nowarn.patch (mainline)
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Wed Aug 21 2013 tonyj@suse.com
- Resolve build errors
- Drop patch perf-tests-ppc64-fix-compile-errors.patch (mainline)
- Refresh patch perl-5.18-nowarn.patch
* Wed Jul 10 2013 tonyj@suse.com
- Add patch 'perf-tests-ppc64-fix-compile-errors.patch' to resolve
  openSUSE:Factory:PowerPC testsuite build errors
* Tue Jul  9 2013 tonyj@suse.com
- Add audit-devel, gtk2-devel and libunwind-devel to support optional
  functionality.
- Add 'perl-5.18-nowarn.patch' to squelch build errors from perl.h
- Add perl_requires
- Fix --version output (copy submakefiles from kernel-source)
- Pass SUSE rpm optflags into make as EXTRA_CFLAGS not CFLAGS
- Stop building with V=1, make output easier to parse
* Tue Dec 25 2012 tonyj@suse.com
- Add /etc/bash_completion.d/perf to %%files (fix build error)
* Wed May 16 2012 toganm@opensuse.org
- Fix build for factory
  * added flex and bison to buildrequires
* Thu May  5 2011 idoenmez@novell.com
- Also copy arch/lib to fix compilation on x86-64
- Correctly depend on libdw-devel to fix dwarf support
- Add newt-devel dependency to enable text user interface
- Re-enable as-needed support since it works now
* Tue Mar  9 2010 tonyj@novell.com
- 2.6.33 changes
  add perf-bench, perf-buildid-list, perf-diff, perf-kmem, perf-probe and
  perf-trace-perl
  [Still pending, update of libdwarf to version > 20081231]
* Thu Nov  5 2009 tonyj@novell.com
- 2.6.32 changes
  add perf-sched, perf-timechart and perf-trace man pages
* Wed Aug 26 2009 aj@suse.de
- Remove libbfd.patch since it does not apply and use
  SUSE_ASNEEDED=0 instead.
- Set flag for asciidoc version 8.
* Sun Aug  2 2009 tonyj@suse.de
- Initial checkin of Performance Counters for Linux (PCL) userspace.
  This builds tools/perf out of kernel-source package and requires
  kernel >= 2.6.31
